Files
odoo_source/odoo/addons/test_performance/security/ir.model.access.csv
T
Adrian Torres 957c78b98f [IMP] base: optimize create on models with property fields
Before this commit, creating a record of a model with at least one
property/company_dependent field would trigger the field's inverse
method regardless of whether an actual value was being passed in for the
field or not.

This means that if no value was given or if the value was the same
as the default value, we would waste precious time in the property
field's inverse method.

With this commit, we do not call the inverse method if:

1) there is no value for it in the vals dict (use default)
2) the value in the vals dict is the same as the default value

As an example, when creating a res.partner record while having account
installed (which introduces a property field in res.partner), the
creation time goes from 24ms to 14ms.

closes odoo/odoo#36267

Signed-off-by: Raphael Collet (rco) <rco@openerp.com>
2019-08-30 16:16:17 +00:00

552 B

1idnamemodel_id:idgroup_id:idperm_readperm_writeperm_createperm_unlink
2access_test_performance_baseaccess_test_performance_basemodel_test_performance_base1111
3access_test_performance_lineaccess_test_performance_linemodel_test_performance_line1111
4access_test_performance_tagaccess_test_performance_tagmodel_test_performance_tag1111
5access_test_performance_baconaccess_test_performance_baconmodel_test_performance_bacon1111
6access_test_performance_eggsaccess_test_performance_eggsmodel_test_performance_eggs1111